===========================================
``psyclone.psyir.symbols.data_type_symbol``
===========================================

.. automodule:: psyclone.psyir.symbols.data_type_symbol

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.symbols.data_type_symbol


Classes
=======

- :py:class:`DataTypeSymbol`:
  Symbol identifying a user-defined type (e.g. a derived type in Fortran).


.. autoclass:: DataTypeSymbol
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: DataTypeSymbol
      :parts: 1
